Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/sugar/activity/activityhandle.py
diff options
context:
space:
mode:
authorDan Williams <dcbw@redhat.com>2007-05-03 03:25:15 (GMT)
committer Dan Williams <dcbw@redhat.com>2007-05-03 03:25:15 (GMT)
commit7774073276de007dbf02c4f36aeeef3d56151bff (patch)
treed3dc6435490f05523159df3e1ec2f5f99d75c3da /sugar/activity/activityhandle.py
parent46d97015e61d9969840f1b36980b80af18e38ac1 (diff)
Make joining asynchronous on the activity side
Diffstat (limited to 'sugar/activity/activityhandle.py')
-rw-r--r--sugar/activity/activityhandle.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/sugar/activity/activityhandle.py b/sugar/activity/activityhandle.py
index c87fb6b..e683ac1 100644
--- a/sugar/activity/activityhandle.py
+++ b/sugar/activity/activityhandle.py
@@ -52,8 +52,8 @@ class ActivityHandle(object):
self.object_id = object_id
self.uri = uri
- def get_presence_service(self):
- """Retrieve the "sharing service" for this activity
+ def get_shared_activity(self):
+ """Retrieve the shared instance of this activity
Uses the PresenceService to find any existing dbus
service which provides sharing mechanisms for this